<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nb_NO">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Information on how to translate KeePassX can be found under:</source>
        <translation>Informasjon om hvordan man oversetter KeePassX finnes under:</translation>
    </message>
    <message>
        <source>Team</source>
        <translation>Team</translation>
    </message>
    <message>
        <source>Developer, Project Admin</source>
        <translation>Utvikler, prosjektadministrator</translation>
    </message>
    <message>
        <source>Web Designer</source>
        <translation>Webdesigner</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Utvikler</translation>
    </message>
    <message>
        <source>Thanks To</source>
        <translation>Takk til</translation>
    </message>
    <message>
        <source>Patches for better MacOS X support</source>
        <translation>Paycher for bedre MacOS X støtte</translation>
    </message>
    <message>
        <source>Main Application Icon</source>
        <translation>Programikon</translation>
    </message>
    <message>
        <source>Various fixes and improvements</source>
        <translation>Diverse forbedringer</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; could not be found.</source>
        <translation>Fil &apos;%1&apos; ble ikke funnet.</translation>
    </message>
    <message>
        <source>Make sure that the program is installed correctly.</source>
        <translation>Sikre deg at programmet er riktig installert.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Current Translation</source>
        <translation>Nåværende oversettelse</translation>
    </message>
    <message>
        <source>None</source>
        <comment>Please replace &apos;None&apos; with the language of your translation</comment>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Forfatter</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>AppName</source>
        <translation>AppName</translation>
    </message>
    <message>
        <source>AppFunc</source>
        <translation>AppFunc</translation>
    </message>
    <message>
        <source>http://keepassx.sourceforge.net</source>
        <translation>http://keepassx.sourceforge.net</translation>
    </message>
    <message>
        <source>keepassx@gmail.com</source>
        <translation>keepassx@gmail.com</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Credits</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Oversettelse</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <source>Copyright (C) 2005 - 2009 KeePassX Team
KeePassX is distributed under the terms of the
General Public License (GPL) version 2.</source>
        <translation>Copyright (C) 2005 - 2009 KeePassX Team
KeePassX er distribuert under betingelsene i lisensen: General Public License (GPL) version 2.</translation>
    </message>
</context>
<context>
    <name>AddBookmarkDlg</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Legg til bokmerke</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Tittel:</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Fil:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Browse...</translation>
    </message>
    <message>
        <source>Edit Bookmark</source>
        <translation>Editer bokmerke</translation>
    </message>
    <message>
        <source>KeePass Databases (*.kdb)</source>
        <translation>KeePass database (*.kdb)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>All filer (*)</translation>
    </message>
</context>
<context>
    <name>AutoTypeDlg</name>
    <message>
        <source>KeePassX - Auto-Type</source>
        <translation>KeePassX - Auto-Inntasting</translation>
    </message>
    <message>
        <source>Click on an entry to auto-type it.</source>
        <translation>Klikk på et element for å taste det inn automatisk.</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Auto-Inntasting</translation>
    </message>
</context>
<context>
    <name>CDbSettingsDlg</name>
    <message>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <source>AES(Rijndael):  256 Bit   (default)</source>
        <translation>AES(Rijndael):  256 Bit   (default)</translation>
    </message>
    <message>
        <source>Twofish:  256 Bit</source>
        <translation>Twofish:  256 Bit</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <source>Please determine the number of encryption rounds.</source>
        <translation>Velg antall krypteringssykler.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is not valid integer value.</source>
        <translation>&apos;%1&apos; er ikke et gyldig tall.</translation>
    </message>
    <message>
        <source>The number of encryption rounds have to be greater than 0.</source>
        <translation>Antall krypteringssykler må være større enn 0.</translation>
    </message>
</context>
<context>
    <name>CEditEntryDlg</name>
    <message>
        <source>Today</source>
        <translation>I dag</translation>
    </message>
    <message>
        <source>1 Week</source>
        <translation>1 uke</translation>
    </message>
    <message>
        <source>2 Weeks</source>
        <translation>2 uker</translation>
    </message>
    <message>
        <source>3 Weeks</source>
        <translation>3 uker</translation>
    </message>
    <message>
        <source>1 Month</source>
        <translation>1 måned</translation>
    </message>
    <message>
        <source>3 Months</source>
        <translation>3 måneder</translation>
    </message>
    <message>
        <source>6 Months</source>
        <translation>6 måneder</translation>
    </message>
    <message>
        <source>1 Year</source>
        <translation>1 år</translation>
    </message>
    <message>
        <source>Calendar...</source>
        <translation>Kalender...</translation>
    </message>
    <message>
        <source>%1 Bit</source>
        <translation>%1 bit</translation>
    </message>
    <message>
        <source>Edit Entry</source>
        <translation>Editer element</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <source>Password and password repetition are not equal.
Please check your input.</source>
        <translation>Passordene er ikke like.  Vennligst kontroller dem.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>[Untitled Entry]</source>
        <translation>[ikke navngitt]</translation>
    </message>
    <message>
        <source>Add Attachment...</source>
        <translation>Legg til vedlegg...</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <source>Could not open file.</source>
        <translation>Kan ikke åpne fil.</translation>
    </message>
    <message>
        <source>The chosen entry has no attachment or it is empty.</source>
        <translation>Det valgte element har ikke vedlegg eller er tomt.</translation>
    </message>
    <message>
        <source>Save Attachment...</source>
        <translation>Lagre vedlegg...</translation>
    </message>
    <message>
        <source>Error while writing the file.</source>
        <translation>Feil under skriving av fil.</translation>
    </message>
    <message>
        <source>Delete Attachment?</source>
        <translation>Slett vedlegg?</translation>
    </message>
    <message>
        <source>You are about to delete the attachment of this entry.
Are you sure?</source>
        <translation>Du er i ferd med å slette vedlegget for dette elementet. Er du sikker?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No, Cancel</source>
        <translation>Nei, avbryt</translation>
    </message>
    <message>
        <source>New Entry</source>
        <translation>Nytt element</translation>
    </message>
</context>
<context>
    <name>CGenPwDialog</name>
    <message>
        <source>Password Generator</source>
        <translation>Passordgenerator</translation>
    </message>
    <message>
        <source>%1 Bits</source>
        <translation>%1 bits</translation>
    </message>
</context>
<context>
    <name>CSelectIconDlg</name>
    <message>
        <source>Replace...</source>
        <translation>Erstatt...</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Add Custom Icon</source>
        <translation>Legg til eget ikon</translation>
    </message>
    <message>
        <source>Pick</source>
        <translation>Velg</translation>
    </message>
    <message>
        <source>Add Icons...</source>
        <translation>Legg til ikoner...</translation>
    </message>
    <message>
        <source>Images (%1)</source>
        <translation>Bilder (%1)</translation>
    </message>
    <message>
        <source>%1: File could not be loaded.</source>
        <translation>%1: Fil kan ikke lastes.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <source>An error occured while loading the icon(s):</source>
        <translation>Feil under lesing av ikon(er):</translation>
    </message>
    <message>
        <source>An error occured while loading the icon.</source>
        <translation>Feil under lesing av ikon.</translation>
    </message>
</context>
<context>
    <name>CSettingsDlg</name>
    <message>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <source>Select a directory...</source>
        <translation>Velg en katalog...</translation>
    </message>
    <message>
        <source>Select an executable...</source>
        <translation>Velg en eksekverbar fil...</translation>
    </message>
    <message>
        <source>System Language</source>
        <translation>Systemspråk</translation>
    </message>
</context>
<context>
    <name>CalendarDialog</name>
    <message>
        <source>Calendar</source>
        <translation>Kalender</translation>
    </message>
</context>
<context>
    <name>CollectEntropyDlg</name>
    <message>
        <source>Random Number Generator</source>
        <translation>Tilfeldig nummer-generator</translation>
    </message>
    <message>
        <source>Collecting entropy...
Please move the mouse and/or press some keys until enought entropy for a reseed of the random number generator is collected.</source>
        <translation>Samler entropi...
Beveg musen eller trykk noen taster på tastaturet til nok entropi er samlet.</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; color:#006400;&quot;&gt;Random pool successfully reseeded!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; color:#006400;&quot;&gt;Funnet nytt frø for tilfeldig nummer!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Entropy Collection</source>
        <translation>Entropisamling</translation>
    </message>
</context>
<context>
    <name>CustomizeDetailViewDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Rich Text Editor</source>
        <translation>Rik-tekst-editor</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Fet</translation>
    </message>
    <message>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>I</source>
        <translation>I</translation>
    </message>
    <message>
        <source>Underlined</source>
        <translation>Understreket</translation>
    </message>
    <message>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <source>Left-Aligned</source>
        <translation>Ventrejustert</translation>
    </message>
    <message>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Sentrert</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>Right-Aligned</source>
        <translation>Høyrejustert</translation>
    </message>
    <message>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <source>Justified</source>
        <translation>Justified</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Tekstfarge</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Tekststørrelse</translation>
    </message>
    <message>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <source>14</source>
        <translation>14</translation>
    </message>
    <message>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <source>18</source>
        <translation>18</translation>
    </message>
    <message>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <source>22</source>
        <translation>22</translation>
    </message>
    <message>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <source>26</source>
        <translation>26</translation>
    </message>
    <message>
        <source>28</source>
        <translation>28</translation>
    </message>
    <message>
        <source>36</source>
        <translation>36</translation>
    </message>
    <message>
        <source>42</source>
        <translation>42</translation>
    </message>
    <message>
        <source>78</source>
        <translation>78</translation>
    </message>
    <message>
        <source>Templates</source>
        <translation>Maler</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>HTML</source>
        <translation>HTML</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Attachment Name</source>
        <translation>Vedlegg</translation>
    </message>
    <message>
        <source>Creation Date</source>
        <translation>Opprettelsesdato</translation>
    </message>
    <message>
        <source>Last Access Date</source>
        <translation>Sist aksessert</translation>
    </message>
    <message>
        <source>Last Modification Date</source>
        <translation>Sist endret</translation>
    </message>
    <message>
        <source>Expiration Date</source>
        <translation>Utgåttdato</translation>
    </message>
    <message>
        <source>Time till Expiration</source>
        <translation>Tid til utgått</translation>
    </message>
</context>
<context>
    <name>Database</name>
    <message>
        <source>Never</source>
        <translation>Aldri</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsDlg</name>
    <message>
        <source>Database Settings</source>
        <translation>Databaseinstillinger</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Kryptering</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algortime:</translation>
    </message>
    <message>
        <source>Encryption Rounds:</source>
        <translation>Krypteringssykler:</translation>
    </message>
    <message>
        <source>Calculate rounds for a 1-second delay on this computer</source>
        <translation>Beregn sykler for et 1-sekunds forsinkelse på denne datamaskin</translation>
    </message>
</context>
<context>
    <name>DetailViewTemplate</name>
    <message>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Creation</source>
        <translation>Opprettelse</translation>
    </message>
    <message>
        <source>Last Access</source>
        <translation>Sist aksessert</translation>
    </message>
    <message>
        <source>Last Modification</source>
        <translation>Sist endret</translation>
    </message>
    <message>
        <source>Expiration</source>
        <translation>Utgåttdato</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
</context>
<context>
    <name>EditEntryDialog</name>
    <message>
        <source>Edit Entry</source>
        <translation>Editer element</translation>
    </message>
    <message>
        <source>Ge&amp;n.</source>
        <translation>Ge&amp;n.</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kvalitet:</translation>
    </message>
    <message>
        <source>Attachment:</source>
        <translation>Vedlegg:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Tittel:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brukernavn:</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>Password Repet.:</source>
        <translation type="obsolete">Gjenta passord:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <source>Expires:</source>
        <translation>Går ut:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Aldri</translation>
    </message>
    <message>
        <source>%1 Bit</source>
        <translation>%1 bit</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditGroupDialog</name>
    <message>
        <source>Group Properties</source>
        <translation>Gruppeegenskaper</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Tittel:</translation>
    </message>
    <message>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
</context>
<context>
    <name>ExpiredEntriesDialog</name>
    <message>
        <source>Expired Entries</source>
        <translation>Utgåtte elementer</translation>
    </message>
    <message>
        <source>Double click on an entry to jump to it.</source>
        <translation>Dobbelklikk på et element for å gå til det.</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Expired</source>
        <translation>Utgått</translation>
    </message>
    <message>
        <source>Expired Entries in the Database</source>
        <translation>Utgåtte elememter i databasen</translation>
    </message>
</context>
<context>
    <name>Export_KeePassX_Xml</name>
    <message>
        <source>KeePassX XML File</source>
        <translation>KeePassX XML Fil</translation>
    </message>
    <message>
        <source>XML Files (*.xml)</source>
        <translation>XML Filer (*.xml)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>All filer (*)</translation>
    </message>
</context>
<context>
    <name>Export_Txt</name>
    <message>
        <source>Text File</source>
        <translation>Text Fil</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>All filer (*)</translation>
    </message>
    <message>
        <source>Text Files (*.txt)</source>
        <translation>Text Filer (*.txt)</translation>
    </message>
</context>
<context>
    <name>ExporterBase</name>
    <message>
        <source>Export Failed</source>
        <translation>Eksport feilet</translation>
    </message>
    <message>
        <source>Export File...</source>
        <translation>Export fil...</translation>
    </message>
</context>
<context>
    <name>FileErrors</name>
    <message>
        <source>No error occurred.</source>
        <translation>Ingen feil.</translation>
    </message>
    <message>
        <source>An error occurred while reading from the file.</source>
        <translation>Feil under lesing av fil.</translation>
    </message>
    <message>
        <source>An error occurred while writing to the file.</source>
        <translation>Feil under skriving av fil.</translation>
    </message>
    <message>
        <source>A fatal error occurred.</source>
        <translation>En alvrolig feil oppsto.</translation>
    </message>
    <message>
        <source>An resource error occurred.</source>
        <translation>En ressursfeil oppsto.</translation>
    </message>
    <message>
        <source>The file could not be opened.</source>
        <translation>Filen kunne ikke åpnes.</translation>
    </message>
    <message>
        <source>The operation was aborted.</source>
        <translation>Handlingen ble avbrutt.</translation>
    </message>
    <message>
        <source>A timeout occurred.</source>
        <translation>En tidsavbrytelse oppsto.</translation>
    </message>
    <message>
        <source>An unspecified error occurred.</source>
        <translation>En uspesifisert feil oppsto.</translation>
    </message>
    <message>
        <source>The file could not be removed.</source>
        <translation>Filen kunne ikke slettes.</translation>
    </message>
    <message>
        <source>The file could not be renamed.</source>
        <translation>Ikke mulig å gi filen nytt navn.</translation>
    </message>
    <message>
        <source>The position in the file could not be changed.</source>
        <translation>Posisjonen i filen kunne ikke endres.</translation>
    </message>
    <message>
        <source>The file could not be resized.</source>
        <translation>Filen kunne ikke endre størrelse.</translation>
    </message>
    <message>
        <source>The file could not be accessed.</source>
        <translation>Filen kunne ikke leses.</translation>
    </message>
    <message>
        <source>The file could not be copied.</source>
        <translation>Filen kunne ikke kopieres.</translation>
    </message>
</context>
<context>
    <name>GenPwDlg</name>
    <message>
        <source>Password Generator</source>
        <translation>Passordgenerator</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valg</translation>
    </message>
    <message>
        <source>Use follo&amp;wing character groups:</source>
        <translation type="obsolete">Bruk følgende tegngruppe:</translation>
    </message>
    <message>
        <source>Alt+W</source>
        <translation type="obsolete">Alt+W</translation>
    </message>
    <message>
        <source>&amp;Lower Letters</source>
        <translation>Små bokstaver</translation>
    </message>
    <message>
        <source>Alt+L</source>
        <translation type="obsolete">Alt+L</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>&amp;Numbers</source>
        <translation>Tall</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation type="obsolete">Alt+S</translation>
    </message>
    <message>
        <source>&amp;Upper Letters</source>
        <translation>Store bokstaver</translation>
    </message>
    <message>
        <source>Alt+U</source>
        <translation type="obsolete">Alt+U</translation>
    </message>
    <message>
        <source>&amp;Special Characters</source>
        <translation>Spesielle tegn</translation>
    </message>
    <message>
        <source>Use &amp;only following characters:</source>
        <translation type="obsolete">Bruk kun følgende tegn:</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Lengde:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kvalitet:</translation>
    </message>
    <message>
        <source>Enable entropy collection</source>
        <translation>Muliggjør entropiinnsamling</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="obsolete">Alt+M</translation>
    </message>
    <message>
        <source>Collect only once per session</source>
        <translation>Samle inn kun en gang pr sesjon</translation>
    </message>
    <message>
        <source>New Password:</source>
        <translation>Nytt passord:</translation>
    </message>
    <message>
        <source>Generate</source>
        <translation>Generer</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Tilfeldig</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>Understrek</translation>
    </message>
    <message>
        <source>&amp;White Spaces</source>
        <translation>Skilletegn</translation>
    </message>
    <message>
        <source>&amp;Minus</source>
        <translation>Minus</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Fjern tegn som ligner</translation>
    </message>
    <message>
        <source>Ensure that password contains characters from every group</source>
        <translation>Sikre at passordet inneholder tegn fra alle grupper</translation>
    </message>
    <message>
        <source>Pronounceable</source>
        <translation>Mulig å uttale</translation>
    </message>
    <message>
        <source>Lower Letters</source>
        <translation>Små bokstaver</translation>
    </message>
    <message>
        <source>Upper Letters</source>
        <translation>Store bokstaver</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Tall</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Spesielle tegn</translation>
    </message>
    <message>
        <source>Use following character groups:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the following characters:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HelpDlg</name>
    <message>
        <source>Previous Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help Contents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Import_KWalletXml</name>
    <message>
        <source>XML Files (*.xml)</source>
        <translation>XML Filer (*.xml)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>All filer (*)</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>Import feilet</translation>
    </message>
    <message>
        <source>Invalid XML data (see stdout for details).</source>
        <translation>Ugyldig XML data (se stdout for detaljer).</translation>
    </message>
    <message>
        <source>Invalid XML file.</source>
        <translation>Ugyldig XML fil.</translation>
    </message>
    <message>
        <source>Document does not contain data.</source>
        <translation>Dokumentet inneholder ingen data.</translation>
    </message>
</context>
<context>
    <name>Import_KeePassX_Xml</name>
    <message>
        <source>KeePass XML Files (*.xml)</source>
        <translation>KeePass XML Filer (*.xml)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>All filer (*)</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>Import feilet</translation>
    </message>
    <message>
        <source>XML parsing error on line %1 column %2:
%3</source>
        <translation>XML-parsing feilet på linje %1 kolonne %2
%3</translation>
    </message>
    <message>
        <source>Parsing error: File is no valid KeePassX XML file.</source>
        <translation>Parse-feil: Filen er ikke en gyldig KeePassX XML fil.</translation>
    </message>
</context>
<context>
    <name>Import_PwManager</name>
    <message>
        <source>PwManager Files (*.pwm)</source>
        <translation>PwManager Filer (*.pwm)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>All filer (*)</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>Import feilet</translation>
    </message>
    <message>
        <source>File is empty.</source>
        <translation>Filen er tom.</translation>
    </message>
    <message>
        <source>File is no valid PwManager file.</source>
        <translation>Filen er ikke en gyldig PwManager fil.</translation>
    </message>
    <message>
        <source>Unsupported file version.</source>
        <translation>Filversjon ikke støttet.</translation>
    </message>
    <message>
        <source>Unsupported hash algorithm.</source>
        <translation>Hash-algortimen er ikke støttet.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Krypteringsalgoritmen er ikke støttet.</translation>
    </message>
    <message>
        <source>Compressed files are not supported yet.</source>
        <translation>Komprimerte filer er ikke støttet enda.</translation>
    </message>
    <message>
        <source>Wrong password.</source>
        <translation>Feil passord.</translation>
    </message>
    <message>
        <source>File is damaged (hash test failed).</source>
        <translation>Filen er skadet (hashtesten feilet).</translation>
    </message>
    <message>
        <source>Invalid XML data (see stdout for details).</source>
        <translation>Ugyldig XML data (se stdout for detaljer).</translation>
    </message>
</context>
<context>
    <name>ImporterBase</name>
    <message>
        <source>Import File...</source>
        <translation>Import fil...</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>Import feilet</translation>
    </message>
</context>
<context>
    <name>Kdb3Database</name>
    <message>
        <source>Could not open file.</source>
        <translation>Kunne ikke åpne fil.</translation>
    </message>
    <message>
        <source>Unexpected file size (DB_TOTAL_SIZE &lt; DB_HEADER_SIZE)</source>
        <translation>Uventet filstørrelse (DB_TOTAL_SIZE &lt; DB_HEADER_SIZE)</translation>
    </message>
    <message>
        <source>Wrong Signature</source>
        <translation>Feil signatur</translation>
    </message>
    <message>
        <source>Unsupported File Version.</source>
        <translation>Filversjon ikke støttet.</translation>
    </message>
    <message>
        <source>Unknown Encryption Algorithm.</source>
        <translation>Ukjent krypteringsalgoritmen.</translation>
    </message>
    <message>
        <source>Unable to initialize the twofish algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown encryption algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decryption failed.
The key is wrong or the file is damaged.</source>
        <translation>Dekrypterng feilet.
Nøkkelen er feil eller filen skadet.</translation>
    </message>
    <message>
        <source>Hash test failed.
The key is wrong or the file is damaged.</source>
        <translation>Hashtest feilet. Nøkkelen er feil eller filen skadet.</translation>
    </message>
    <message>
        <source>Unexpected error: Offset is out of range.</source>
        <translation>En uspesifisert feil oppsto: Offset er utenfor grensen.</translation>
    </message>
    <message>
        <source>Invalid group tree.</source>
        <translation>Ugyldig gruppetre.</translation>
    </message>
    <message>
        <source>Key file is empty.</source>
        <translation>Nøkkelfil er tom.</translation>
    </message>
    <message>
        <source>The database must contain at least one group.</source>
        <translation>Databasen må inneholde minst en gruppe.</translation>
    </message>
    <message>
        <source>Unable to initalize the twofish algorithm.</source>
        <translation type="obsolete">Ikke mulig å inisialisere twofish-algoritmen.</translation>
    </message>
    <message>
        <source>The database has been opened read-only.</source>
        <translation>Databsen er åpnet for bare-les.</translation>
    </message>
</context>
<context>
    <name>Kdb3Database::EntryHandle</name>
    <message>
        <source>Bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
</context>
<context>
    <name>KeepassEntryView</name>
    <message>
        <source>Delete?</source>
        <translation>Slett?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <source>At least one group must exist before adding an entry.</source>
        <translation>Minst en gruppe må finnes før et element opprettes.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
    <message>
        <source>Comments</source>
        <translation>Kommentarer</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Går ut</translation>
    </message>
    <message>
        <source>Creation</source>
        <translation>Opprettelse</translation>
    </message>
    <message>
        <source>Last Change</source>
        <translation>Siste endring</translation>
    </message>
    <message>
        <source>Last Access</source>
        <translation>Sist aksessert</translation>
    </message>
    <message>
        <source>Attachment</source>
        <translation>Vedlegg</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this entry?</source>
        <translation>Er du sikker på at du vil slette dette elementet?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete these %1 entries?</source>
        <translation>Er du sikker på at du vil slette disse %1 elementene?</translation>
    </message>
</context>
<context>
    <name>KeepassGroupView</name>
    <message>
        <source>Search Results</source>
        <translation>Søkeresultat</translation>
    </message>
    <message>
        <source>Delete?</source>
        <translation>Slett?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this group, all its child groups and all their entries?</source>
        <translation>Er du sikker at på at du vil slette denne gruppen, alle undergrupper og alle deres elementer?</translation>
    </message>
</context>
<context>
    <name>KeepassMainWindow</name>
    <message>
        <source>Ready</source>
        <translation>Klar</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="obsolete">Låst</translation>
    </message>
    <message>
        <source>Unlocked</source>
        <translation type="obsolete">Ulåst</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Shift+Ctrl+S</source>
        <translation>Shift+Ctrl+S</translation>
    </message>
    <message>
        <source>Shift+Ctrl+F</source>
        <translation>Shift+Ctrl+F</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <source>The database file does not exist.</source>
        <translation>Databasefilen finnes ikke.</translation>
    </message>
    <message>
        <source>Loading Database...</source>
        <translation>Laster databasen...</translation>
    </message>
    <message>
        <source>Loading Failed</source>
        <translation>Lasting feilet</translation>
    </message>
    <message>
        <source>Unknown error while loading database.</source>
        <translation>Ukjent feil i forbindelse med lasting av databasen.</translation>
    </message>
    <message>
        <source>The following error occured while opening the database:</source>
        <translation>Følgende feil oppsto når databasen ble forsøkt åpnet:</translation>
    </message>
    <message>
        <source>Save modified file?</source>
        <translation>Lagre endret fil?</translation>
    </message>
    <message>
        <source>new</source>
        <translation>ny</translation>
    </message>
    <message>
        <source>Open Database...</source>
        <translation>Åpne database...</translation>
    </message>
    <message>
        <source>KeePass Databases (*.kdb)</source>
        <translation>KeePass database (*.kdb)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>All filer (*)</translation>
    </message>
    <message>
        <source>Expired</source>
        <translation>Utgått</translation>
    </message>
    <message>
        <source>1 Month</source>
        <translation>1 måned</translation>
    </message>
    <message>
        <source>%1 Months</source>
        <translation>%1 måneder</translation>
    </message>
    <message>
        <source>1 Year</source>
        <translation>1 år</translation>
    </message>
    <message>
        <source>%1 Years</source>
        <translation>%1 år</translation>
    </message>
    <message>
        <source>1 Day</source>
        <translation>1 dag</translation>
    </message>
    <message>
        <source>%1 Days</source>
        <translation>%1 dager</translation>
    </message>
    <message>
        <source>less than 1 day</source>
        <translation>mindre enn 1 dag</translation>
    </message>
    <message>
        <source>Clone Entry</source>
        <translation>Klon element</translation>
    </message>
    <message>
        <source>Delete Entry</source>
        <translation>Slett Element</translation>
    </message>
    <message>
        <source>Clone Entries</source>
        <translation>Klon elementer</translation>
    </message>
    <message>
        <source>Delete Entries</source>
        <translation>Slett elementer</translation>
    </message>
    <message>
        <source>File could not be saved.</source>
        <translation>Filen kunne ikke lages.</translation>
    </message>
    <message>
        <source>Save Database...</source>
        <translation>Lagre database...</translation>
    </message>
    <message>
        <source>Un&amp;lock Workspace</source>
        <translation>Lås opp arbeidsflate</translation>
    </message>
    <message>
        <source>&amp;Lock Workspace</source>
        <translation>Lås arbeidsflate</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Vis statslinje</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Database locked</source>
        <translation>Database låst</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked.
This means that either someone else has opened the file or KeePassX crashed last time it opened the database.

Do you want to open it anyway?</source>
        <translation>Databasen du forsøker å åpne er låst.
Dette betyr at neon andre bruker den eller at KeePassX kræsjet forrige gang denne databsen ble åpnet.

Vil du åpne den allikevel?</translation>
    </message>
    <message>
        <source>The current file was modified.
Do you want to save the changes?</source>
        <translation>Filen er endret.
Vil du lagre endringene?</translation>
    </message>
    <message>
        <source>Couldn&apos;t remove database lock file.</source>
        <translation>Kan ikke slette låsefilen til databasen.</translation>
    </message>
    <message>
        <source>Open read-only</source>
        <translation>Åpne for bare-les</translation>
    </message>
    <message>
        <source>Couldn&apos;t create lock file. Opening the database read-only.</source>
        <translation>Kanikke lage låsefil. Åpner databsen for bare-les.</translation>
    </message>
    <message>
        <source>Couldn&apos;t create database lock file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; could not be found.</source>
        <translation>Fil &apos;%1&apos; ble ikke funnet.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>KeePassX</source>
        <translation>KeePassX</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Grupper</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <source>&amp;Export to...</source>
        <translation>Export til...</translation>
    </message>
    <message>
        <source>&amp;Import from...</source>
        <translation>Import fra...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>View</translation>
    </message>
    <message>
        <source>E&amp;xtras</source>
        <translation>Ekstra</translation>
    </message>
    <message>
        <source>&amp;Open Database...</source>
        <translation>Åpne database...</translation>
    </message>
    <message>
        <source>&amp;Close Database</source>
        <translation>Lukk database</translation>
    </message>
    <message>
        <source>&amp;Save Database</source>
        <translation>Lagre database</translation>
    </message>
    <message>
        <source>Save Database &amp;As...</source>
        <translation>Lagre database som...</translation>
    </message>
    <message>
        <source>&amp;Database Settings...</source>
        <translation>Databaseinnstillinger...</translation>
    </message>
    <message>
        <source>Change &amp;Master Key...</source>
        <translation>Endre masternøkkel...</translation>
    </message>
    <message>
        <source>&amp;Lock Workspace</source>
        <translation>Lås arbeidsflate</translation>
    </message>
    <message>
        <source>&amp;Settings...</source>
        <translation>Innstillinger...</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <source>&amp;KeePassX Handbook...</source>
        <translation>KeePassX Håndbok...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Skjul</translation>
    </message>
    <message>
        <source>Recycle Bin...</source>
        <translation>Søppelkasse...</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>Bokmerker</translation>
    </message>
    <message>
        <source>Toolbar &amp;Icon Size</source>
        <translation>Ikonstørrelse på verktøylinjen</translation>
    </message>
    <message>
        <source>&amp;Columns</source>
        <translation>Kolonner</translation>
    </message>
    <message>
        <source>&amp;Manage Bookmarks...</source>
        <translation>Ordne bokmerker...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Avslutt</translation>
    </message>
    <message>
        <source>&amp;Edit Group...</source>
        <translation>Editer gruppe...</translation>
    </message>
    <message>
        <source>&amp;Delete Group</source>
        <translation>Slett gruppe</translation>
    </message>
    <message>
        <source>Copy Password &amp;to Clipboard</source>
        <translation>Kopier passord til utklippstavlen</translation>
    </message>
    <message>
        <source>Copy &amp;Username to Clipboard</source>
        <translation>Kopier brukernavn til utklippstavlen</translation>
    </message>
    <message>
        <source>&amp;Open URL</source>
        <translation>Åpne URL</translation>
    </message>
    <message>
        <source>&amp;Save Attachment As...</source>
        <translation>Lagre vedlegg som...</translation>
    </message>
    <message>
        <source>Add &amp;New Entry...</source>
        <translation>Legg til nytt element...</translation>
    </message>
    <message>
        <source>&amp;View/Edit Entry...</source>
        <translation>Se på/editer element...</translation>
    </message>
    <message>
        <source>De&amp;lete Entry</source>
        <translation>Slett element</translation>
    </message>
    <message>
        <source>&amp;Clone Entry</source>
        <translation>Klon element</translation>
    </message>
    <message>
        <source>Search &amp;in Database...</source>
        <translation>Søk i database...</translation>
    </message>
    <message>
        <source>Search in this &amp;Group...</source>
        <translation>Søk i denne gruppen...</translation>
    </message>
    <message>
        <source>Show &amp;Entry Details</source>
        <translation>Se på elementdetaljer</translation>
    </message>
    <message>
        <source>Hide &amp;Usernames</source>
        <translation>Skjul brukernavn</translation>
    </message>
    <message>
        <source>Hide &amp;Passwords</source>
        <translation>Skjul passord</translation>
    </message>
    <message>
        <source>&amp;Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>User&amp;name</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>&amp;URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>&amp;Password</source>
        <translation>Passord</translation>
    </message>
    <message>
        <source>&amp;Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>E&amp;xpires</source>
        <translation>Går ut</translation>
    </message>
    <message>
        <source>C&amp;reation</source>
        <translation>Opprettet</translation>
    </message>
    <message>
        <source>&amp;Last Change</source>
        <translation>Siste endring</translation>
    </message>
    <message>
        <source>Last &amp;Access</source>
        <translation>Sist aksessert</translation>
    </message>
    <message>
        <source>A&amp;ttachment</source>
        <translation>Vedlegg</translation>
    </message>
    <message>
        <source>Show &amp;Statusbar</source>
        <translation>Vis statslinje</translation>
    </message>
    <message>
        <source>&amp;Perform AutoType</source>
        <translation>Utfør auto-inntasting</translation>
    </message>
    <message>
        <source>&amp;16x16</source>
        <translation>16x16</translation>
    </message>
    <message>
        <source>&amp;22x22</source>
        <translation>22x22</translation>
    </message>
    <message>
        <source>2&amp;8x28</source>
        <translation>28x28</translation>
    </message>
    <message>
        <source>&amp;New Database...</source>
        <translation>New database...</translation>
    </message>
    <message>
        <source>&amp;Password Generator...</source>
        <translation>Passordgenerator...</translation>
    </message>
    <message>
        <source>&amp;Group (search results only)</source>
        <translation type="obsolete">Gruppe (kun søkeresultat)</translation>
    </message>
    <message>
        <source>Show &amp;Expired Entries...</source>
        <translation>Vis utgåtte elementer...</translation>
    </message>
    <message>
        <source>&amp;Add Bookmark...</source>
        <translation>Legg til bokmerke...</translation>
    </message>
    <message>
        <source>Bookmark &amp;this Database...</source>
        <translation>Legg til bokmerke for denne databasen...</translation>
    </message>
    <message>
        <source>&amp;Add New Subgroup...</source>
        <translation>Legg til ny undergruppe...</translation>
    </message>
    <message>
        <source>Copy URL to Clipboard</source>
        <translation>Kopier URL til utklippstavle</translation>
    </message>
    <message>
        <source>Add New Group...</source>
        <translation>Legg til ny gruppe...</translation>
    </message>
    <message>
        <source>&amp;Entries</source>
        <translation>Elementer</translation>
    </message>
    <message>
        <source>&amp;Groups</source>
        <translation>Grupper</translation>
    </message>
    <message>
        <source>Sort groups</source>
        <translation>Sorter grupper</translation>
    </message>
    <message>
        <source>&amp;Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Minimize Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageBookmarksDlg</name>
    <message>
        <source>Manage Bookmarks</source>
        <translation>Ordne bokmerker</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Enter Master Key</source>
        <translation>Skriv inn masternøkkel</translation>
    </message>
    <message>
        <source>Set Master Key</source>
        <translation>Sett masternøkkel</translation>
    </message>
    <message>
        <source>Change Master Key</source>
        <translation>Endre masternøkkel</translation>
    </message>
    <message>
        <source>Database Key</source>
        <translation>Databasenøkkel</translation>
    </message>
    <message>
        <source>Last File</source>
        <translation>Siste fil</translation>
    </message>
    <message>
        <source>Select a Key File</source>
        <translation>Velg en nøkkelfil</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>All filer (*)</translation>
    </message>
    <message>
        <source>Key Files (*.key)</source>
        <translation>Nøkkelfiler (*.key)</translation>
    </message>
    <message>
        <source>Please enter a Password or select a key file.</source>
        <translation>Legg inn passord eller velg en nøkkelfil.</translation>
    </message>
    <message>
        <source>Please enter a Password.</source>
        <translation>Legg inn passord.</translation>
    </message>
    <message>
        <source>Please provide a key file.</source>
        <translation>Finn nøkkelfil.</translation>
    </message>
    <message>
        <source>%1:
No such file or directory.</source>
        <translation>%1:
Fil eller katalog ikke funnet.</translation>
    </message>
    <message>
        <source>The selected key file or directory is not readable.</source>
        <translation>Nøkkelfilen eller katalogen er ikke lesbar.</translation>
    </message>
    <message>
        <source>The given directory does not contain any key files.</source>
        <translation>Katalogen inneholder ingen nøkkelfiler.</translation>
    </message>
    <message>
        <source>The given directory contains more then one key files.
Please specify the key file directly.</source>
        <translation>Katalogen inneholder mer enn en nøkkelfil. Spesifiser filen.</translation>
    </message>
    <message>
        <source>%1:
File is not readable.</source>
        <translation>%1: Filen er ikke lesbar.</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Lag nøkkelfil...</translation>
    </message>
</context>
<context>
    <name>PasswordDlg</name>
    <message>
        <source>Last File</source>
        <translation>Siste fil</translation>
    </message>
    <message>
        <source>Enter a Password and/or choose a key file.</source>
        <translation>Legg inn passord og/eller velg nøkkelfil.</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Nøkkel</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <source>&amp;Browse...</source>
        <translation>Browse...</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="obsolete">Alt+B</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Nøkkelfil:</translation>
    </message>
    <message>
        <source>Generate Key File...</source>
        <translation>Generer nøkkelfil...</translation>
    </message>
    <message>
        <source>Please repeat your password:</source>
        <translation>Gjenta passord:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Tilbake</translation>
    </message>
    <message>
        <source>Passwords are not equal.</source>
        <translation>Passordene er ikke like.</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
</context>
<context>
    <name>Search_Dlg</name>
    <message>
        <source>Search...</source>
        <translation>Søk...</translation>
    </message>
    <message>
        <source>Include:</source>
        <translation>Inkluder:</translation>
    </message>
    <message>
        <source>Pass&amp;words</source>
        <translation>Passord</translation>
    </message>
    <message>
        <source>Alt+W</source>
        <translation type="obsolete">Alt+W</translation>
    </message>
    <message>
        <source>A&amp;nhang</source>
        <translation>A&amp;nhang</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>U&amp;RLs</source>
        <translation>URLer</translation>
    </message>
    <message>
        <source>Alt+R</source>
        <translation type="obsolete">Alt+R</translation>
    </message>
    <message>
        <source>C&amp;omments</source>
        <translation>Kommentarer</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Usernames</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Alt+U</source>
        <translation type="obsolete">Alt+U</translation>
    </message>
    <message>
        <source>&amp;Titles</source>
        <translation>Tittler</translation>
    </message>
    <message>
        <source>Alt+T</source>
        <translation type="obsolete">Alt+T</translation>
    </message>
    <message>
        <source>&amp;Case Sensitive</source>
        <translation>Case Sensitive</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
    <message>
        <source>Regular E&amp;xpression</source>
        <translation>Regulært uttrykk</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation type="obsolete">Alt+X</translation>
    </message>
    <message>
        <source>Include Subgroups (recursive)</source>
        <translation>Inkluder undergrupper (rekursivt)</translation>
    </message>
    <message>
        <source>Search For:</source>
        <translation>Søk etter:</translation>
    </message>
</context>
<context>
    <name>SelectIconDlg</name>
    <message>
        <source>Icon Selection</source>
        <translation>Ikonvalg</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <source>Show system tray icon</source>
        <translation>Show system tray icon</translation>
    </message>
    <message>
        <source>Minimize to tray instead of taskbar</source>
        <translation>Minimize to tray instead of taskbar</translation>
    </message>
    <message>
        <source>Minimize to tray when clicking the main window&apos;s close button</source>
        <translation type="unfinished">Minimize to tray when clicking the main window&apos;s close button</translation>
    </message>
    <message>
        <source>Remember last opened file</source>
        <translation>Husk sist åpnet fil</translation>
    </message>
    <message utf8="true">
        <source>Alt+Ö</source>
        <translation type="obsolete">Alt+Ö</translation>
    </message>
    <message>
        <source>Remember last key type and location</source>
        <translation>Husk forrige nøkkeltype og plassering</translation>
    </message>
    <message>
        <source>Start minimized</source>
        <translation>Start minimert</translation>
    </message>
    <message>
        <source>Start locked</source>
        <translation>Start låst</translation>
    </message>
    <message>
        <source>Save recent directories of file dialogs</source>
        <translation>Save recent directories of file dialogs</translation>
    </message>
    <message>
        <source>Clear History Now</source>
        <translation>Slett historikk nå</translation>
    </message>
    <message>
        <source>Always ask before deleting entries or groups</source>
        <translation>Spør alltid før sletting av grupper eller elementer</translation>
    </message>
    <message>
        <source>Banner Color</source>
        <translation>Bannerfarge</translation>
    </message>
    <message>
        <source>Text Color:</source>
        <translation>tekstfarge:</translation>
    </message>
    <message>
        <source>Change...</source>
        <translation>Endre...</translation>
    </message>
    <message>
        <source>Color 2:</source>
        <translation>Farge 2:</translation>
    </message>
    <message>
        <source>C&amp;hange...</source>
        <translation>Endre...</translation>
    </message>
    <message>
        <source>Alt+H</source>
        <translation type="obsolete">Alt+H</translation>
    </message>
    <message>
        <source>Color 1:</source>
        <translation>Farge 1:</translation>
    </message>
    <message>
        <source>Alternating Row Colors</source>
        <translation>Alternerende radfarger</translation>
    </message>
    <message>
        <source>Customize Entry Detail View...</source>
        <translation>Tilpass elementdetaljer-viewet...</translation>
    </message>
    <message>
        <source>Group tree at start-up:</source>
        <translation>Gruppetre ved oppstart:</translation>
    </message>
    <message>
        <source>Restore last state</source>
        <translation>Gjenopprett siste tilstand</translation>
    </message>
    <message>
        <source>Expand all items</source>
        <translation>Ekspander alle elementer</translation>
    </message>
    <message>
        <source>Do not expand any item</source>
        <translation>Ikke ekspander elementer</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sikkerhet</translation>
    </message>
    <message>
        <source>Edit Entry Dialog</source>
        <translation>Editer Element dialog</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>Clear clipboard after:</source>
        <translation>Slett utklippstavle etter:</translation>
    </message>
    <message>
        <source>Lock workspace when minimizing the main window</source>
        <translation>Lås arbeidsflaten når programmet minimeres</translation>
    </message>
    <message>
        <source>You can disable several features of KeePassX here according to your needs in order to keep the user interface slim.</source>
        <translation>Du kan slå av funksjonalitet i KeePassX her for å få et rent brukergrensesnitt.</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Bokmerker</translation>
    </message>
    <message>
        <source>Plug-Ins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Gnome Desktop Integration (Gtk 2.x)</source>
        <translation>Gnome Desktop-integrasjon (Gtk 2.x)</translation>
    </message>
    <message>
        <source>KDE 4 Desktop Integration</source>
        <translation>KDE 4 Desktop-integrasjon</translation>
    </message>
    <message>
        <source>You need to restart the program before the changes take effect.</source>
        <translation>Du må starte programmet på nytt for å se endringene.</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Konfiguerer...</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avansert</translation>
    </message>
    <message>
        <source>Auto-Type Fine Tuning</source>
        <translation>Auto-inntasting fintuning</translation>
    </message>
    <message>
        <source>Time between the activation of an auto-type action by the user and the first simulated key stroke.</source>
        <translation>Tid mellom aktivering av auto-inntasting-handling av brukeren og frste simulrte tasting.</translation>
    </message>
    <message>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <source>Pre-Gap:</source>
        <translation>Pre-Gap:</translation>
    </message>
    <message>
        <source>Key Stroke Delay:</source>
        <translation>Tasteforsinkelse:</translation>
    </message>
    <message>
        <source>Delay between two simulated key strokes. Increase this if Auto-Type is randomly skipping characters.</source>
        <translation>Forsinkelse mellom to simulerte taster. Øk dene hvis auto-inntasting hopper over tegn.</translation>
    </message>
    <message>
        <source>Custom Browser Command</source>
        <translation>Egen nettleserkommando</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Browse</translation>
    </message>
    <message>
        <source>Media Root:</source>
        <translation>Media Root:</translation>
    </message>
    <message>
        <source>The directory where storage devices like CDs and memory sticks are normally mounted.</source>
        <translation>Katalogen hvor CDer og minnebrikker vanligvis er montert.</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Browse...</translation>
    </message>
    <message>
        <source>Enable this if you want to use your bookmarks and the last opened file independet from their absolute paths. This is especially useful when using KeePassX portably and therefore with changing mount points in the file system.</source>
        <translation>Velg denne hvis du ønsker å bruke dine bokmerker og siste filer uavhengig av deres absolutte stier.  Dette er nyttig når man bruker KeePassX portabelt og dermed har forskjellige &apos;mount-points&apos; i filsystemet.</translation>
    </message>
    <message>
        <source>Save relative paths (bookmarks and last file)</source>
        <translation>Lagre relavtive stier (bokmerker og siste fil)</translation>
    </message>
    <message>
        <source>Global Auto-Type Shortcut:</source>
        <translation>Globalt auto-innstasting hurtigvalg:</translation>
    </message>
    <message>
        <source>Automatically save database on exit and workspace locking</source>
        <translation>Automaitsk lagre databasen ved avslutning eller låsing</translation>
    </message>
    <message>
        <source>Show plain text passwords in:</source>
        <translation>Vis klarttekst passord i:</translation>
    </message>
    <message>
        <source>Database Key Dialog</source>
        <translation>Databasenøkkel-dialog</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sukunder</translation>
    </message>
    <message>
        <source>Lock database after inactivity of</source>
        <translation>Lås databasen etter inaktivtet</translation>
    </message>
    <message>
        <source>Use entries&apos; title to match the window for Global Auto-Type</source>
        <translation>Bruk elementers tittel for å matche vinduet for global auto-inntasting</translation>
    </message>
    <message>
        <source>General (1)</source>
        <translation>Generelt (1)</translation>
    </message>
    <message>
        <source>General (2)</source>
        <translation>Generelt (2)</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Språk</translation>
    </message>
    <message>
        <source>Save backups of modified entries into the &apos;Backup&apos; group</source>
        <translation>Lagre backups av endrede elementer i &apos;Backup&apos; gruppen</translation>
    </message>
    <message>
        <source>Delete backup entries older than:</source>
        <translation>Slett backupelementer eldre enn:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dager</translation>
    </message>
    <message>
        <source>Automatically save database after every change</source>
        <translation>Automaitsk lagre databasen etter hver endring</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Språk:</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Forfatter:</translation>
    </message>
    <message>
        <source>Show window always on top</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutWidget</name>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>AltGr</source>
        <translation>AltGr</translation>
    </message>
    <message>
        <source>Win</source>
        <translation>Win</translation>
    </message>
</context>
<context>
    <name>SimplePasswordDialog</name>
    <message>
        <source>Enter your Password</source>
        <translation>Legg inn passord</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
</context>
<context>
    <name>TargetWindowDlg</name>
    <message>
        <source>Auto-Type: Select Target Window</source>
        <translation>Auto-inntasting: Velg målvindu</translation>
    </message>
    <message>
        <source>To specify the target window, either select an existing currently-opened window
from the drop-down list, or enter the window title manually:</source>
        <translation>For å velge et målvindu, enten velg et åpent vindy fra drop-down-listen
eller skriv inn vindustittelen manuelt:</translation>
    </message>
</context>
<context>
    <name>Translation</name>
    <message>
        <source>$TRANSLATION_AUTHOR</source>
        <translation>Fredrik Rødland</translation>
    </message>
    <message>
        <source>$TRANSLATION_AUTHOR_EMAIL</source>
        <comment>Here you can enter your email or homepage if you want.</comment>
        <translation>translate [aaaatttt] rodland.no - http://rodland.no</translation>
    </message>
    <message>
        <source>$LANGUAGE_NAME</source>
        <comment>Insert your language name in the format: English (United States)</comment>
        <translation>Norwegian bokmål (Norway)</translation>
    </message>
</context>
<context>
    <name>WorkspaceLockedWidget</name>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;The workspace is locked.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Arbeidsflatebn er låst.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Unlock</source>
        <translation>Lås opp</translation>
    </message>
    <message>
        <source>Close Database</source>
        <translation>Lukk database</translation>
    </message>
</context>
</TS>
